// utils.js

/**
 * Splits a given string into words, attempting to handle various case formats.
 * 
 * Supported detection:
 * - camelCase: "myVariableName" -> ["my", "Variable", "Name"]
 * - PascalCase: "MyVariableName" -> ["My", "Variable", "Name"]
 * - snake_case: "my_variable_name" -> ["my", "variable", "name"]
 * - kebab-case: "my-variable-name" -> ["my", "variable", "name"]
 * 
 * Once split, we'll normalize all words to lowercase or handle acronyms.
 */
export function splitIntoWords(str) {
    if (!str) return [];
  
    // Check for snake_case or kebab-case
    if (str.includes('_')) {
      return str.split('_');
    } else if (str.includes('-')) {
      return str.split('-');
    } else {
      // Likely camelCase or PascalCase
      // Split by transitions from lower-to-upper or by uppercase letters
      return str
        .replace(/([a-z0-9])([A-Z])/g, '$1 $2')
        .split(' ')
        .map((w) => w.trim());
    }
  }
  
  /**
   * Detect the probable case format of a string.
   * This is optional and just for reference.
   */
  export function detectCase(str) {
    if (str.includes('_')) return 'snake';
    if (str.includes('-')) return 'kebab';
    if (str[0] === str[0].toUpperCase()) return 'pascal';
    return 'camel';
  }
  
  /**
   * Handle acronyms in the words array.
   * If `handleAcronyms` is true, acronyms (e.g., "API") should remain uppercase.
   * Otherwise, we convert everything to lowercase except leading chars for Pascal.
   */
  export function handleAcronymsInWords(words, options) {
    if (options.handleAcronyms) {
      return words.map(word => {
        return word.replace(/([A-Z]+)([A-Z][a-z])/g, '$1_$2').toLowerCase();
      });
    }
    return words;
  }